package com.siulkilulki.model;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.mockito.Mock;
import org.mockito.Mockito;
import org.mockito.MockitoAnnotations;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


public class TestMeetings
{
    @Mock
    Meeting mockedMeeting1;
    @Mock
    Meeting mockedMeeting2;
    @Mock
    Meeting mockedMeeting3;

    @Before
    public void setup()
    {
        MockitoAnnotations.initMocks( this );
    }

    @Test
    public void shouldPutMeeting2BeetweenMeeting1andMeeting3()
    {
        Mockito.when( mockedMeeting1.getDateStart() ).thenReturn( new Date( 1 ) );
        Mockito.when( mockedMeeting2.getDateStart() ).thenReturn( new Date( 2 ) );
        Mockito.when( mockedMeeting3.getDateStart() ).thenReturn( new Date( 3 ) );

        List<Meeting> meetingList = new ArrayList<>();
        meetingList.add( mockedMeeting1 );
        meetingList.add( mockedMeeting3 );
        Meetings meetings = new Meetings( meetingList );
        meetings.addMeeting( mockedMeeting2 );
        Assert.assertEquals( mockedMeeting2, meetings.getMeetingAt( 1 ) );
    }

    @Test
    public void shouldAddMeetingWhenMeetingsListIsEmpty()
    {
        Mockito.when( mockedMeeting1.getDateStart() ).thenReturn( new Date( 1 ) );
        Meetings meetings = new Meetings();
        meetings.addMeeting( mockedMeeting1 );
        Assert.assertEquals( mockedMeeting1, meetings.getMeetingAt( 0 ) );
    }

    @Test
    public void shouldAddAsFirstElementInMeetings()
    {
        Mockito.when( mockedMeeting1.getDateStart() ).thenReturn( new Date( 1 ) );
        Mockito.when( mockedMeeting2.getDateStart() ).thenReturn( new Date( 2 ) );
        List<Meeting> meetingList = new ArrayList<>();
        meetingList.add( mockedMeeting2 );
        Meetings meetings = new Meetings( meetingList );
        meetings.addMeeting( mockedMeeting1 );
        Assert.assertEquals( mockedMeeting1, meetings.getMeetingAt( 0 ) );
    }

    @Test
    public void shouldAddAsLastElementInMeetings()
    {
        Mockito.when( mockedMeeting1.getDateStart() ).thenReturn( new Date( 1 ) );
        Mockito.when( mockedMeeting2.getDateStart() ).thenReturn( new Date( 2 ) );
        List<Meeting> meetingList = new ArrayList<>();
        meetingList.add( mockedMeeting1 );
        Meetings meetings = new Meetings( meetingList );
        meetings.addMeeting( mockedMeeting2 );
        Assert.assertEquals( mockedMeeting2, meetings.getMeetingAt( 1 ) );
    }

    @Test
    public void shouldAddMeetingIfThereIsMeetingWithTheSameDateInTheBoundsOfMeetingsList()
    {
        Mockito.when( mockedMeeting1.getDateStart() ).thenReturn( new Date( 1 ) );
        List<Meeting> meetingList = new ArrayList<>();
        meetingList.add( mockedMeeting1 );
        Meetings meetings = new Meetings( meetingList );
        meetings.addMeeting( mockedMeeting1 );
        Assert.assertEquals( mockedMeeting1, meetings.getMeetingAt( 1 ) );
    }
}
